# Welcome to geogo


[![image](https://img.shields.io/pypi/v/geogo.svg)](https://pypi.python.org/pypi/geogo)


**A python package for geospatial analysis and mapping**


-   Free software: MIT License
-   Documentation: <https://jlhammel.github.io/geogo>


## Features

- Process geospatial data

## Usage
```python
import geogo
import os
```